/*
 * Secure eXtended Message Passing framework
 * Secure eXtended Transport layer implementation: (libsxt)
 * - very similar to SSH2/TLS
 * - using already proven and tested crypto algos
 * - better than TLS for message passing
 *
 * Some useful wrappers and structures
 *
 * (c) Alexander Vdolainen 2016 <avdolainen@zoho.com>
 *
 * libsxmp is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * libsxmp is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.";
 *
 */

#ifndef __SXT_SXTCRYPT_H__
#define __SXT_SXTCRYPT_H__

#include <openssl/sha.h>

typedef SHA512_CTX* SHA512CTX;

#define SHA512_DIGEST_LEN SHA512_DIGEST_LENGTH

struct _lcrypt_cipher_priv
{
  void *key;
  void *ivec;
};

int lcrypt_init_ciphers(void);
void lcrypt_cleanup_keystub(sxt_cipher_t *);
int lcrypt_alloc_keystub(sxt_cipher_t *);

/* sxt wrapper around random numbers */
int sxt_get_random(void *data, int len, int pseudo);

/* wrappers around SHA512 */
SHA512CTX sha512_init(void);
void sha512_update(SHA512CTX c, const void *data, unsigned long len);
void sha512_final(unsigned char *md, SHA512CTX c);


#endif
